about summary refs log tree commit diff
path: root/sysdeps/unix/sysv/linux/x86/gettimeofday.c
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/unix/sysv/linux/x86/gettimeofday.c')
-rw-r--r--sysdeps/unix/sysv/linux/x86/gettimeofday.c11
1 files changed, 9 insertions, 2 deletions
diff --git a/sysdeps/unix/sysv/linux/x86/gettimeofday.c b/sysdeps/unix/sysv/linux/x86/gettimeofday.c
index c820fd767b..440cb0243a 100644
--- a/sysdeps/unix/sysv/linux/x86/gettimeofday.c
+++ b/sysdeps/unix/sysv/linux/x86/gettimeofday.c
@@ -21,6 +21,13 @@
 #ifdef SHARED
 
 # include <dl-vdso.h>
+# include <errno.h>
+
+static int
+__gettimeofday_syscall (struct timeval *tv, struct timezone *tz)
+{
+  return INLINE_SYSCALL (gettimeofday, 2, tv, tz);
+}
 
 void *gettimeofday_ifunc (void) __asm__ ("__gettimeofday");
 
@@ -29,9 +36,9 @@ gettimeofday_ifunc (void)
 {
   PREPARE_VERSION_KNOWN (linux26, LINUX_2_6);
 
   /* If the vDSO is not available we fall back on the old vsyscall.  */
   return (_dl_vdso_vsym ("__vdso_gettimeofday", &linux26)
-	  ?: GETTIMEOFAY_FALLBACK);
+	  ?: (void*) (&__gettimeofday_syscall));
 }
 asm (".type __gettimeofday, %gnu_indirect_function");
@@ -29,9 +36,9 @@ gettimeofday_ifunc (void)
   PREPARE_VERSION_KNOWN (linux26, LINUX_2_6);
 
-  /* If the vDSO is not available we fall back on the old vsyscall.  */
+  /* If the vDSO is not available we fall back to syscall.  */
   return (_dl_vdso_vsym ("__vdso_gettimeofday", &linux26)